@@ -1,7 +1,13 @@
 import os
 from pathlib import Path
+from bfcl_eval.constants.category_mapping import VERSION_PREFIX
 
-VLLM_PORT = 1053
+LOCAL_SERVER_PORT = 1053
+LOCAL_SERVER_MAX_CONCURRENT_REQUEST = 100
+
+# Price got from Lambda Cloud, 23.92 per hour for 8x H100, on-demand pay as you go total price
+# Reference: https://lambda.ai/pricing
+H100_X8_PRICE_PER_HOUR = 23.92
 
 # Directory of the installed package
 PACKAGE_ROOT = Path(__file__).resolve().parents[1]
@@ -21,8 +27,11 @@ TEST_IDS_TO_GENERATE_PATH = PROJECT_ROOT / "test_case_ids_to_generate.json"
 PROMPT_PATH = PACKAGE_ROOT / "data"
 MULTI_TURN_FUNC_DOC_PATH = PROMPT_PATH / "multi_turn_func_doc"
 POSSIBLE_ANSWER_PATH = PROMPT_PATH / "possible_answer"
+MEMORY_PREREQ_CONVERSATION_PATH = PROMPT_PATH / "memory_prereq_conversation"
 UTILS_PATH = PACKAGE_ROOT / "scripts"
+FORMAT_SENSITIVITY_IDS_PATH = PROMPT_PATH / f"{VERSION_PREFIX}_format_sensitivity.json"
 
+RESULT_FILE_PATTERN = f"{VERSION_PREFIX}_*_result.json"
 
 RED_FONT = "\033[91m"
 RESET = "\033[0m"
