@@ -3,20 +3,20 @@ from typing import Optional
 
 from bfcl_eval.model_handler.api_inference.claude import ClaudeHandler
 from bfcl_eval.model_handler.api_inference.cohere import CohereHandler
-from bfcl_eval.model_handler.api_inference.databricks import DatabricksHandler
 from bfcl_eval.model_handler.api_inference.deepseek import DeepSeekAPIHandler
 from bfcl_eval.model_handler.api_inference.dm_cito import DMCitoHandler
 from bfcl_eval.model_handler.api_inference.fireworks import FireworksHandler
 from bfcl_eval.model_handler.api_inference.functionary import FunctionaryHandler
 from bfcl_eval.model_handler.api_inference.gemini import GeminiHandler
+from bfcl_eval.model_handler.api_inference.glm import GLMAPIHandler
 from bfcl_eval.model_handler.api_inference.gogoagent import GoGoAgentHandler
 from bfcl_eval.model_handler.api_inference.gorilla import GorillaHandler
 from bfcl_eval.model_handler.api_inference.grok import GrokHandler
+from bfcl_eval.model_handler.api_inference.kimi import KimiHandler
 from bfcl_eval.model_handler.api_inference.ling import LingAPIHandler
 from bfcl_eval.model_handler.api_inference.mining import MiningHandler
 from bfcl_eval.model_handler.api_inference.mistral import MistralHandler
 from bfcl_eval.model_handler.api_inference.nemotron import NemotronHandler
-from bfcl_eval.model_handler.api_inference.nexus import NexusHandler
 from bfcl_eval.model_handler.api_inference.nova import NovaHandler
 from bfcl_eval.model_handler.api_inference.novita import NovitaHandler
 from bfcl_eval.model_handler.api_inference.nvidia import NvidiaHandler
@@ -30,24 +30,20 @@ from bfcl_eval.model_handler.api_inference.qwen import (
     QwenAPIHandler,
 )
 from bfcl_eval.model_handler.api_inference.writer import WriterHandler
-from bfcl_eval.model_handler.api_inference.yi import YiHandler
 from bfcl_eval.model_handler.local_inference.arch import ArchHandler
 from bfcl_eval.model_handler.local_inference.bielik import BielikHandler
-from bfcl_eval.model_handler.local_inference.deepseek import DeepseekHandler
-from bfcl_eval.model_handler.local_inference.deepseek_coder import DeepseekCoderHandler
+from bfcl_eval.model_handler.local_inference.bitagent import BitAgentHandler
 from bfcl_eval.model_handler.local_inference.deepseek_reasoning import (
     DeepseekReasoningHandler,
 )
 from bfcl_eval.model_handler.local_inference.falcon_fc import Falcon3FCHandler
 from bfcl_eval.model_handler.local_inference.gemma import GemmaHandler
-from bfcl_eval.model_handler.local_inference.glaive import GlaiveHandler
 from bfcl_eval.model_handler.local_inference.glm import GLMHandler
 from bfcl_eval.model_handler.local_inference.granite import (
     GraniteFunctionCallingHandler,
 )
 from bfcl_eval.model_handler.local_inference.granite_3 import Granite3FCHandler
 from bfcl_eval.model_handler.local_inference.hammer import HammerHandler
-from bfcl_eval.model_handler.local_inference.hermes import HermesHandler
 from bfcl_eval.model_handler.local_inference.llama import LlamaHandler
 from bfcl_eval.model_handler.local_inference.llama_3_1 import LlamaHandler_3_1
 from bfcl_eval.model_handler.local_inference.minicpm import MiniCPMHandler
@@ -125,7 +121,7 @@ api_inference_model_map = {
         model_handler=GorillaHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "DeepSeek-R1-0528": ModelConfig(
@@ -164,30 +160,78 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "gpt-4.5-preview-2025-02-27": ModelConfig(
-        model_name="gpt-4.5-preview-2025-02-27",
-        display_name="GPT-4.5-Preview-2025-02-27 (Prompt)",
-        url="https://openai.com/index/introducing-gpt-4-5/",
+    "gpt-5-2025-08-07-FC": ModelConfig(
+        model_name="gpt-5-2025-08-07-FC",
+        display_name="GPT-5-2025-08-07 (FC)",
+        url="https://openai.com/index/introducing-gpt-5/",
         org="OpenAI",
         license="Proprietary",
         model_handler=OpenAIResponsesHandler,
-        input_price=75,
-        output_price=150,
+        input_price=1.25,
+        output_price=10,
+        is_fc_model=True,
+        underscore_to_dot=True,
+    ),
+    "gpt-5-2025-08-07": ModelConfig(
+        model_name="gpt-5-2025-08-07",
+        display_name="GPT-5-2025-08-07 (Prompt)",
+        url="https://openai.com/index/introducing-gpt-5/",
+        org="OpenAI",
+        license="Proprietary",
+        model_handler=OpenAIResponsesHandler,
+        input_price=1.25,
+        output_price=10,
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "gpt-4.5-preview-2025-02-27-FC": ModelConfig(
-        model_name="gpt-4.5-preview-2025-02-27-FC",
-        display_name="GPT-4.5-Preview-2025-02-27 (FC)",
-        url="https://openai.com/index/introducing-gpt-4-5/",
+    "gpt-5-mini-2025-08-07-FC": ModelConfig(
+        model_name="gpt-5-mini-2025-08-07-FC",
+        display_name="GPT-5-mini-2025-08-07 (FC)",
+        url="https://openai.com/index/introducing-gpt-5/",
         org="OpenAI",
         license="Proprietary",
         model_handler=OpenAIResponsesHandler,
-        input_price=75,
-        output_price=150,
+        input_price=0.25,
+        output_price=2,
         is_fc_model=True,
         underscore_to_dot=True,
     ),
+    "gpt-5-mini-2025-08-07": ModelConfig(
+        model_name="gpt-5-mini-2025-08-07",
+        display_name="GPT-5-mini-2025-08-07 (Prompt)",
+        url="https://openai.com/index/introducing-gpt-5/",
+        org="OpenAI",
+        license="Proprietary",
+        model_handler=OpenAIResponsesHandler,
+        input_price=0.25,
+        output_price=2,
+        is_fc_model=False,
+        underscore_to_dot=False,
+    ),
+    "gpt-5-nano-2025-08-07-FC": ModelConfig(
+        model_name="gpt-5-nano-2025-08-07-FC",
+        display_name="GPT-5-nano-2025-08-07 (FC)",
+        url="https://openai.com/index/introducing-gpt-5/",
+        org="OpenAI",
+        license="Proprietary",
+        model_handler=OpenAIResponsesHandler,
+        input_price=0.05,
+        output_price=0.4,
+        is_fc_model=True,
+        underscore_to_dot=True,
+    ),
+    "gpt-5-nano-2025-08-07": ModelConfig(
+        model_name="gpt-5-nano-2025-08-07",
+        display_name="GPT-5-nano-2025-08-07 (Prompt)",
+        url="https://openai.com/index/introducing-gpt-5/",
+        org="OpenAI",
+        license="Proprietary",
+        model_handler=OpenAIResponsesHandler,
+        input_price=0.05,
+        output_price=0.4,
+        is_fc_model=False,
+        underscore_to_dot=False,
+    ),
     "gpt-4.1-2025-04-14-FC": ModelConfig(
         model_name="gpt-4.1-2025-04-14-FC",
         display_name="GPT-4.1-2025-04-14 (FC)",
@@ -356,9 +400,9 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "claude-opus-4-20250514": ModelConfig(
-        model_name="claude-opus-4-20250514",
-        display_name="Claude-Opus-4-20250514 (Prompt)",
+    "claude-opus-4-1-20250805": ModelConfig(
+        model_name="claude-opus-4-1-20250805",
+        display_name="Claude-Opus-4-1-20250805 (Prompt)",
         url="https://www.anthropic.com/news/claude-4",
         org="Anthropic",
         license="Proprietary",
@@ -368,9 +412,9 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "claude-opus-4-20250514-FC": ModelConfig(
-        model_name="claude-opus-4-20250514",
-        display_name="Claude-Opus-4-20250514 (FC)",
+    "claude-opus-4-1-20250805-FC": ModelConfig(
+        model_name="claude-opus-4-1-20250805",
+        display_name="Claude-Opus-4-1-20250805 (FC)",
         url="https://www.anthropic.com/news/claude-4",
         org="Anthropic",
         license="Proprietary",
@@ -437,7 +481,7 @@ api_inference_model_map = {
         model_handler=NovaHandler,
         input_price=0.8,
         output_price=3.2,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=True,
     ),
     "nova-lite-v1.0": ModelConfig(
@@ -449,7 +493,7 @@ api_inference_model_map = {
         model_handler=NovaHandler,
         input_price=0.06,
         output_price=0.24,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=True,
     ),
     "nova-micro-v1.0": ModelConfig(
@@ -461,7 +505,7 @@ api_inference_model_map = {
         model_handler=NovaHandler,
         input_price=0.035,
         output_price=0.14,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=True,
     ),
     "open-mistral-nemo-2407": ModelConfig(
@@ -512,9 +556,9 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "mistral-small-2503": ModelConfig(
-        model_name="mistral-small-2503",
-        display_name="Mistral-Small-2503 (Prompt)",
+    "mistral-small-2506": ModelConfig(
+        model_name="mistral-small-2506",
+        display_name="Mistral-Small-2506 (Prompt)",
         url="https://docs.mistral.ai/guides/model-selection/",
         org="Mistral AI",
         license="Proprietary",
@@ -524,9 +568,9 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "mistral-small-2503-FC": ModelConfig(
-        model_name="mistral-small-2503-FC",
-        display_name="Mistral-small-2503 (FC)",
+    "mistral-small-2506-FC": ModelConfig(
+        model_name="mistral-small-2506-FC",
+        display_name="Mistral-small-2506 (FC)",
         url="https://docs.mistral.ai/guides/model-selection/",
         org="Mistral AI",
         license="Proprietary",
@@ -572,18 +616,6 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=False,
     ),
-    "Nexusflow-Raven-v2": ModelConfig(
-        model_name="Nexusflow-Raven-v2",
-        display_name="Nexusflow-Raven-v2 (FC)",
-        url="https://huggingface.co/Nexusflow/NexusRaven-V2-13B",
-        org="Nexusflow",
-        license="Apache 2.0",
-        model_handler=NexusHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=False,
-        underscore_to_dot=False,
-    ),
     "gemini-2.5-flash-lite-preview-06-17-FC": ModelConfig(
         model_name="gemini-2.5-flash-lite-preview-06-17-FC",
         display_name="Gemini-2.5-Flash-Lite-Preview-06-17 (FC)",
@@ -680,30 +712,6 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "databricks-dbrx-instruct": ModelConfig(
-        model_name="databricks-dbrx-instruct",
-        display_name="DBRX-Instruct (Prompt)",
-        url="https://www.databricks.com/blog/introducing-dbrx-new-state-art-open-llm",
-        org="Databricks",
-        license="Databricks Open Model",
-        model_handler=DatabricksHandler,
-        input_price=2.25,
-        output_price=6.75,
-        is_fc_model=False,
-        underscore_to_dot=False,
-    ),
-    "command-r-plus-FC": ModelConfig(
-        model_name="command-r-plus-FC",
-        display_name="Command-R-Plus (FC)",
-        url="https://txt.cohere.com/command-r-plus-microsoft-azure",
-        org="Cohere For AI",
-        license="cc-by-nc-4.0",
-        model_handler=CohereHandler,
-        input_price=3,
-        output_price=15,
-        is_fc_model=True,
-        underscore_to_dot=True,
-    ),
     "command-r7b-12-2024-FC": ModelConfig(
         model_name="command-r7b-12-2024-FC",
         display_name="Command R7B (FC)",
@@ -728,17 +736,17 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "snowflake/arctic": ModelConfig(
-        model_name="snowflake/arctic",
-        display_name="Snowflake/snowflake-arctic-instruct (Prompt)",
-        url="https://huggingface.co/Snowflake/snowflake-arctic-instruct",
-        org="Snowflake",
-        license="apache-2.0",
-        model_handler=NvidiaHandler,
+    "command-a-reasoning-08-2025-FC": ModelConfig(
+        model_name="command-a-reasoning-08-2025-FC",
+        display_name="Command A Reasoning (FC)",
+        url="https://cohere.com/blog/command-a-reasoning",
+        org="Cohere",
+        license="CC-BY-NC 4.0 License (w/ Acceptable Use Addendum)",
+        model_handler=CohereHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
-        underscore_to_dot=False,
+        is_fc_model=True,
+        underscore_to_dot=True,
     ),
     "nvidia/llama-3.1-nemotron-ultra-253b-v1": ModelConfig(
         model_name="nvidia/llama-3.1-nemotron-ultra-253b-v1",
@@ -785,12 +793,12 @@ api_inference_model_map = {
         model_handler=WriterHandler,
         input_price=5,
         output_price=12,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
-    "grok-3-beta-FC": ModelConfig(
-        model_name="grok-3-beta-FC",
-        display_name="Grok-3-beta (FC)",
+    "grok-4-0709-FC": ModelConfig(
+        model_name="grok-4-0709-FC",
+        display_name="Grok-4-0709 (FC)",
         url="https://docs.x.ai/docs/models",
         org="xAI",
         license="Proprietary",
@@ -800,9 +808,9 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "grok-3-beta": ModelConfig(
-        model_name="grok-3-beta",
-        display_name="Grok-3-beta (Prompt)",
+    "grok-4-0709": ModelConfig(
+        model_name="grok-4-0709",
+        display_name="Grok-4-0709 (Prompt)",
         url="https://docs.x.ai/docs/models",
         org="xAI",
         license="Proprietary",
@@ -812,30 +820,6 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "grok-3-mini-beta-FC": ModelConfig(
-        model_name="grok-3-mini-beta-FC",
-        display_name="Grok-3-mini-beta (FC)",
-        url="https://docs.x.ai/docs/models",
-        org="xAI",
-        license="Proprietary",
-        model_handler=GrokHandler,
-        input_price=0.3,
-        output_price=0.5,
-        is_fc_model=True,
-        underscore_to_dot=True,
-    ),
-    "grok-3-mini-beta": ModelConfig(
-        model_name="grok-3-mini-beta",
-        display_name="Grok-3-mini-beta (Prompt)",
-        url="https://docs.x.ai/docs/models",
-        org="xAI",
-        license="Proprietary",
-        model_handler=GrokHandler,
-        input_price=0.3,
-        output_price=0.5,
-        is_fc_model=False,
-        underscore_to_dot=False,
-    ),
     "qwen3-0.6b-FC": ModelConfig(
         model_name="qwen3-0.6b-FC",
         display_name="Qwen3-0.6B (FC)",
@@ -848,18 +832,6 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "phronetic-ai/RZN-T": ModelConfig(
-        model_name="phronetic-ai/RZN-T",
-        display_name="RZN-T (Prompt)",
-        url="https://huggingface.co/phronetic-ai/RZN-T",
-        org="Phronetic AI",
-        license="apache-2.0",
-        model_handler=QwenHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=False,
-        underscore_to_dot=False,
-    ),
     "qwen3-0.6b": ModelConfig(
         model_name="qwen3-0.6b",
         display_name="Qwen3-0.6B (Prompt)",
@@ -992,10 +964,10 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "qwen3-30b-a3b-FC": ModelConfig(
-        model_name="qwen3-30b-a3b-FC",
-        display_name="Qwen3-30B-A3B (FC)",
-        url="https://huggingface.co/Qwen/Qwen3-30B-A3B",
+    "qwen3-30b-a3b-instruct-2507-FC": ModelConfig(
+        model_name="qwen3-30b-a3b-instruct-2507",
+        display_name="Qwen3-30B-A3B-Instruct-2507 (FC)",
+        url="https://huggingface.co/Qwen/Qwen3-30B-A3B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenAPIHandler,
@@ -1004,10 +976,10 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "qwen3-30b-a3b": ModelConfig(
-        model_name="qwen3-30b-a3b",
-        display_name="Qwen3-30B-A3B (Prompt)",
-        url="https://huggingface.co/Qwen/Qwen3-30B-A3B",
+    "qwen3-30b-a3b-instruct-2507": ModelConfig(
+        model_name="qwen3-30b-a3b-instruct-2507",
+        display_name="Qwen3-30B-A3B-Instruct-2507 (Prompt)",
+        url="https://huggingface.co/Qwen/Qwen3-30B-A3B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenAPIHandler,
@@ -1016,22 +988,22 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "qwen3-235b-a22b-FC": ModelConfig(
-        model_name="qwen3-235b-a22b-FC",
-        display_name="Qwen3-235B-A22B (FC)",
-        url="https://huggingface.co/Qwen/Qwen3-235B-A22B",
+    "qwen3-235b-a22b-instruct-2507-FC": ModelConfig(
+        model_name="qwen3-235b-a22b-instruct-2507-FC",
+        display_name="Qwen3-235B-A22B-Instruct-2507 (FC)",
+        url="https://huggingface.co/Qwen/Qwen3-235B-A22B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenAPIHandler,
         input_price=None,
         output_price=None,
         is_fc_model=True,
-        underscore_to_dot=True,
+        underscore_to_dot=False,
     ),
-    "qwen3-235b-a22b": ModelConfig(
-        model_name="qwen3-235b-a22b",
-        display_name="Qwen3-235B-A22B (Prompt)",
-        url="https://huggingface.co/Qwen/Qwen3-235B-A22B",
+    "qwen3-235b-a22b-instruct-2507": ModelConfig(
+        model_name="qwen3-235b-a22b-instruct-2507",
+        display_name="Qwen3-235B-A22B-Instruct-2507 (Prompt)",
+        url="https://huggingface.co/Qwen/Qwen3-235B-A22B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenAPIHandler,
@@ -1066,14 +1038,14 @@ api_inference_model_map = {
     ),
     "xiaoming-14B": ModelConfig(
         model_name="xiaoming-14B",
-        display_name="xiaoming-14B (Prompt)",
+        display_name="xiaoming-14B (FC)",
         url="https://www.mininglamp.com/",
         org="Mininglamp",
         license="Proprietary",
         model_handler=MiningHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "DM-Cito-8B-v2": ModelConfig(
@@ -1100,6 +1072,54 @@ api_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
+    "glm-4.5-FC": ModelConfig(
+        model_name="glm-4.5-FC",
+        display_name="GLM-4.5 (FC)",
+        url="https://huggingface.co/zai-org/GLM-4.5",
+        org="Zhipu AI",
+        license="MIT",
+        model_handler=GLMAPIHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=True,
+    ),
+    "glm-4.5-air-FC": ModelConfig(
+        model_name="glm-4.5-air-FC",
+        display_name="GLM-4.5-Air (FC)",
+        url="https://huggingface.co/zai-org/GLM-4.5-Air",
+        org="Zhipu AI",
+        license="MIT",
+        model_handler=GLMAPIHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=True,
+    ),
+    "kimi-k2-0711-preview-FC": ModelConfig(
+        model_name="moonshotai/Kimi-K2-Instruct-FC",
+        display_name="Moonshotai-Kimi-K2-Instruct (FC)",
+        url="https://huggingface.co/moonshotai/Kimi-K2-Instruct",
+        org="MoonshotAI",
+        license="modified-mit",
+        model_handler=KimiHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=True,
+    ),
+    "kimi-k2-0711-preview": ModelConfig(
+        model_name="moonshotai/Kimi-K2-Instruct",
+        display_name="Moonshotai-Kimi-K2-Instruct (Prompt)",
+        url="https://huggingface.co/moonshotai/Kimi-K2-Instruct",
+        org="MoonshotAI",
+        license="modified-mit",
+        model_handler=KimiHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=False,
+        underscore_to_dot=False,
+    ),
 }
 
 # Inference through local hosting
@@ -1281,7 +1301,7 @@ local_inference_model_map = {
         model_handler=SalesforceLlamaHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "Salesforce/Llama-xLAM-2-8b-fc-r": ModelConfig(
@@ -1293,7 +1313,7 @@ local_inference_model_map = {
         model_handler=SalesforceLlamaHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "Salesforce/xLAM-2-32b-fc-r": ModelConfig(
@@ -1305,7 +1325,7 @@ local_inference_model_map = {
         model_handler=SalesforceQwenHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "Salesforce/xLAM-2-3b-fc-r": ModelConfig(
@@ -1317,7 +1337,7 @@ local_inference_model_map = {
         model_handler=SalesforceQwenHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "Salesforce/xLAM-2-1b-fc-r": ModelConfig(
@@ -1329,7 +1349,7 @@ local_inference_model_map = {
         model_handler=SalesforceQwenHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "mistralai/Ministral-8B-Instruct-2410": ModelConfig(
@@ -1413,7 +1433,7 @@ local_inference_model_map = {
         model_handler=GraniteFunctionCallingHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=True,
     ),
     "MadeAgents/Hammer2.1-7b": ModelConfig(
@@ -1425,7 +1445,7 @@ local_inference_model_map = {
         model_handler=HammerHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "MadeAgents/Hammer2.1-3b": ModelConfig(
@@ -1437,7 +1457,7 @@ local_inference_model_map = {
         model_handler=HammerHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "MadeAgents/Hammer2.1-1.5b": ModelConfig(
@@ -1449,7 +1469,7 @@ local_inference_model_map = {
         model_handler=HammerHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "MadeAgents/Hammer2.1-0.5b": ModelConfig(
@@ -1461,7 +1481,7 @@ local_inference_model_map = {
         model_handler=HammerHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=False,
     ),
     "THUDM/glm-4-9b-chat": ModelConfig(
@@ -1473,7 +1493,7 @@ local_inference_model_map = {
         model_handler=GLMHandler,
         input_price=None,
         output_price=None,
-        is_fc_model=False,
+        is_fc_model=True,
         underscore_to_dot=True,
     ),
     "Qwen/Qwen3-0.6B-FC": ModelConfig(
@@ -1524,10 +1544,10 @@ local_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-4B-FC": ModelConfig(
-        model_name="Qwen/Qwen3-4B-FC",
-        display_name="Qwen3-4B (FC)",
-        url="https://huggingface.co/Qwen/Qwen3-4B",
+    "Qwen/Qwen3-4B-Instruct-2507-FC": ModelConfig(
+        model_name="Qwen/Qwen3-4B-Instruct-2507-FC",
+        display_name="Qwen3-4B-Instruct-2507 (FC)",
+        url="https://huggingface.co/Qwen/Qwen3-4B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenFCHandler,
@@ -1536,10 +1556,10 @@ local_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-4B": ModelConfig(
-        model_name="Qwen/Qwen3-4B",
-        display_name="Qwen3-4B (Prompt)",
-        url="https://huggingface.co/Qwen/Qwen3-4B",
+    "Qwen/Qwen3-4B-Instruct-2507": ModelConfig(
+        model_name="Qwen/Qwen3-4B-Instruct-2507",
+        display_name="Qwen3-4B-Instruct-2507 (Prompt)",
+        url="https://huggingface.co/Qwen/Qwen3-4B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenHandler,
@@ -1620,10 +1640,10 @@ local_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-30B-A3B-FC": ModelConfig(
-        model_name="Qwen/Qwen3-30B-A3B-FC",
-        display_name="Qwen3-30B-A3B (FC)",
-        url="https://huggingface.co/Qwen/Qwen3-30B-A3B",
+    "Qwen/Qwen3-30B-A3B-Instruct-2507-FC": ModelConfig(
+        model_name="Qwen/Qwen3-30B-A3B-Instruct-2507-FC",
+        display_name="Qwen3-30B-A3B-Instruct-2507 (FC)",
+        url="https://huggingface.co/Qwen/Qwen3-30B-A3B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenFCHandler,
@@ -1632,10 +1652,10 @@ local_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-30B-A3B": ModelConfig(
-        model_name="Qwen/Qwen3-30B-A3B",
-        display_name="Qwen3-30B-A3B (Prompt)",
-        url="https://huggingface.co/Qwen/Qwen3-30B-A3B",
+    "Qwen/Qwen3-30B-A3B-Instruct-2507": ModelConfig(
+        model_name="Qwen/Qwen3-30B-A3B-Instruct-2507",
+        display_name="Qwen3-30B-A3B-Instruct-2507 (Prompt)",
+        url="https://huggingface.co/Qwen/Qwen3-30B-A3B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenHandler,
@@ -1644,10 +1664,10 @@ local_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-235B-A22B-FC": ModelConfig(
-        model_name="Qwen/Qwen3-235B-A22B-FC",
-        display_name="Qwen3-235B-A22B (FC)",
-        url="https://huggingface.co/Qwen/Qwen3-235B-A22B",
+    "Qwen/Qwen3-235B-A22B-Instruct-2507-FC": ModelConfig(
+        model_name="Qwen/Qwen3-235B-A22B-Instruct-2507",
+        display_name="Qwen3-235B-A22B-Instruct-2507 (FC)",
+        url="https://huggingface.co/Qwen/Qwen3-235B-A22B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenFCHandler,
@@ -1656,10 +1676,10 @@ local_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=False,
     ),
-    "Qwen/Qwen3-235B-A22B": ModelConfig(
-        model_name="Qwen/Qwen3-235B-A22B",
-        display_name="Qwen3-235B-A22B (Prompt)",
-        url="https://huggingface.co/Qwen/Qwen3-235B-A22B",
+    "Qwen/Qwen3-235B-A22B-Instruct-2507": ModelConfig(
+        model_name="Qwen/Qwen3-235B-A22B-Instruct-2507",
+        display_name="Qwen3-235B-A22B-Instruct-2507 (Prompt)",
+        url="https://huggingface.co/Qwen/Qwen3-235B-A22B-Instruct-2507",
         org="Qwen",
         license="apache-2.0",
         model_handler=QwenHandler,
@@ -1848,6 +1868,54 @@ local_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
+    "katanemo/Arch-Agent-1.5B": ModelConfig(
+        model_name="katanemo/Arch-Agent-1.5B",
+        display_name="Arch-Agent-1.5B",
+        url="https://huggingface.co/katanemo/Arch-Agent-1.5B",
+        org="katanemo",
+        license="katanemo-research",
+        model_handler=ArchHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
+    "katanemo/Arch-Agent-3B": ModelConfig(
+        model_name="katanemo/Arch-Agent-3B",
+        display_name="Arch-Agent-3B",
+        url="https://huggingface.co/katanemo/Arch-Agent-3B",
+        org="katanemo",
+        license="katanemo-research",
+        model_handler=ArchHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
+    "katanemo/Arch-Agent-7B": ModelConfig(
+        model_name="katanemo/Arch-Agent-7B",
+        display_name="Arch-Agent-7B",
+        url="https://huggingface.co/katanemo/Arch-Agent-7B",
+        org="katanemo",
+        license="katanemo-research",
+        model_handler=ArchHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
+    "katanemo/Arch-Agent-32B": ModelConfig(
+        model_name="katanemo/Arch-Agent-32B",
+        display_name="Arch-Agent-32B",
+        url="https://huggingface.co/katanemo/Arch-Agent-32B",
+        org="katanemo",
+        license="katanemo-research",
+        model_handler=ArchHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
     "BitAgent/BitAgent-8B": ModelConfig(
         model_name="BitAgent/BitAgent-8B",
         display_name="BitAgent-8B",
@@ -1860,6 +1928,18 @@ local_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
+    "BitAgent/BitAgent-Bounty-8B": ModelConfig(
+        model_name="BitAgent/BitAgent-Bounty-8B",
+        display_name="BitAgent-Bounty-8B",
+        url="https://huggingface.co/BitAgent/BitAgent-Bounty-8B",
+        org="Bittensor",
+        license="Apache-2.0",
+        model_handler=BitAgentHandler,
+        input_price=None,
+        output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
     "ThinkAgents/ThinkAgent-1B": ModelConfig(
         model_name="ThinkAgents/ThinkAgent-1B",
         display_name="ThinkAgent-1B (FC)",
@@ -1869,6 +1949,18 @@ local_inference_model_map = {
         model_handler=ThinkAgentHandler,
         input_price=None,
         output_price=None,
+        is_fc_model=True,
+        underscore_to_dot=False,
+    ),
+    "phronetic-ai/RZN-T": ModelConfig(
+        model_name="phronetic-ai/RZN-T",
+        display_name="RZN-T (Prompt)",
+        url="https://huggingface.co/phronetic-ai/RZN-T",
+        org="Phronetic AI",
+        license="apache-2.0",
+        model_handler=QwenHandler,
+        input_price=None,
+        output_price=None,
         is_fc_model=False,
         underscore_to_dot=False,
     ),
@@ -1876,7 +1968,7 @@ local_inference_model_map = {
 
 # Inference through third-party inference platforms for open-source models
 third_party_inference_model_map = {
-    # Novita AI
+    # Via Novita AI Endpoint
     "meta-llama/llama-4-maverick-17b-128e-instruct-fp8-novita": ModelConfig(
         model_name="meta-llama/llama-4-maverick-17b-128e-instruct-fp8-novita",
         display_name="Llama-4-Maverick-17B-128E-Instruct-FP8 (Prompt) (Novita)",
@@ -1949,6 +2041,7 @@ third_party_inference_model_map = {
         is_fc_model=False,
         underscore_to_dot=False,
     ),
+    # Via Qwen Agent Framework
     "qwen3-4b-think-FC": ModelConfig(
         model_name="qwen3-4b-think-FC",
         display_name="Qwen3-4B-Think (FC)",
@@ -1973,54 +2066,6 @@ third_party_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "katanemo/Arch-Agent-1.5B": ModelConfig(
-        model_name="katanemo/Arch-Agent-1.5B",
-        display_name="Arch-Agent-1.5B",
-        url="https://huggingface.co/katanemo/Arch-Agent-1.5B",
-        org="katanemo",
-        license="katanemo-research",
-        model_handler=ArchHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=True,
-        underscore_to_dot=False,
-    ),
-    "katanemo/Arch-Agent-3B": ModelConfig(
-        model_name="katanemo/Arch-Agent-3B",
-        display_name="Arch-Agent-3B",
-        url="https://huggingface.co/katanemo/Arch-Agent-3B",
-        org="katanemo",
-        license="katanemo-research",
-        model_handler=ArchHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=True,
-        underscore_to_dot=False,
-    ),
-    "katanemo/Arch-Agent-7B": ModelConfig(
-        model_name="katanemo/Arch-Agent-7B",
-        display_name="Arch-Agent-7B",
-        url="https://huggingface.co/katanemo/Arch-Agent-7B",
-        org="katanemo",
-        license="katanemo-research",
-        model_handler=ArchHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=True,
-        underscore_to_dot=False,
-    ),
-    "katanemo/Arch-Agent-32B": ModelConfig(
-        model_name="katanemo/Arch-Agent-32B",
-        display_name="Arch-Agent-32B",
-        url="https://huggingface.co/katanemo/Arch-Agent-32B",
-        org="katanemo",
-        license="katanemo-research",
-        model_handler=ArchHandler,
-        input_price=None,
-        output_price=None,
-        is_fc_model=True,
-        underscore_to_dot=False,
-    ),
 }
 
 
@@ -2029,3 +2074,6 @@ MODEL_CONFIG_MAPPING = {
     **local_inference_model_map,
     **third_party_inference_model_map,
 }
+
+# Uncomment to get the supported_models.py file contents
+# print(repr(list(MODEL_CONFIG_MAPPING.keys())))
