@@ -17,24 +17,28 @@ SUPPORTED_MODELS = [
     "DeepSeek-R1-0528",
     "DeepSeek-R1-0528-FC",
     "DeepSeek-V3-0324-FC",
-    "gpt-4.5-preview-2025-02-27",
-    "gpt-4.5-preview-2025-02-27-FC",
+    "gpt-5-2025-08-07-FC",
+    "gpt-5-2025-08-07",
+    "gpt-5-mini-2025-08-07-FC",
+    "gpt-5-mini-2025-08-07",
+    "gpt-5-nano-2025-08-07-FC",
+    "gpt-5-nano-2025-08-07",
     "gpt-4.1-2025-04-14-FC",
     "gpt-4.1-2025-04-14",
     "gpt-4.1-mini-2025-04-14-FC",
     "gpt-4.1-mini-2025-04-14",
     "gpt-4.1-nano-2025-04-14-FC",
     "gpt-4.1-nano-2025-04-14",
-    "o3-2025-04-16",
-    "o3-2025-04-16-FC",
-    "o4-mini-2025-04-16",
-    "o4-mini-2025-04-16-FC",
     "gpt-4o-2024-11-20",
     "gpt-4o-2024-11-20-FC",
     "gpt-4o-mini-2024-07-18",
     "gpt-4o-mini-2024-07-18-FC",
-    "claude-opus-4-20250514",
-    "claude-opus-4-20250514-FC",
+    "o3-2025-04-16",
+    "o3-2025-04-16-FC",
+    "o4-mini-2025-04-16",
+    "o4-mini-2025-04-16-FC",
+    "claude-opus-4-1-20250805",
+    "claude-opus-4-1-20250805-FC",
     "claude-sonnet-4-20250514",
     "claude-sonnet-4-20250514-FC",
     "claude-3-5-haiku-20241022",
@@ -46,12 +50,11 @@ SUPPORTED_MODELS = [
     "open-mistral-nemo-2407-FC",
     "mistral-large-2411",
     "mistral-large-2411-FC",
-    "mistral-small-2503",
-    "mistral-small-2503-FC",
+    "mistral-small-2506",
+    "mistral-small-2506-FC",
     "mistral-medium-2505",
     "mistral-medium-2505-FC",
     "firefunction-v2-FC",
-    "Nexusflow-Raven-v2",
     "gemini-2.5-flash-lite-preview-06-17-FC",
     "gemini-2.5-flash-lite-preview-06-17",
     "gemini-2.5-flash-FC",
@@ -60,19 +63,14 @@ SUPPORTED_MODELS = [
     "gemini-2.5-pro",
     "meetkai/functionary-small-v3.1-FC",
     "meetkai/functionary-medium-v3.1-FC",
-    "databricks-dbrx-instruct",
-    "command-r-plus-FC",
     "command-r7b-12-2024-FC",
     "command-a-03-2025-FC",
-    "snowflake/arctic",
     "nvidia/llama-3.1-nemotron-ultra-253b-v1",
     "nvidia/nemotron-4-340b-instruct",
     "BitAgent/GoGoAgent",
     "palmyra-x-004",
-    "grok-3-beta-FC",
-    "grok-3-beta",
-    "grok-3-mini-beta-FC",
-    "grok-3-mini-beta",
+    "grok-4-0709-FC",
+    "grok-4-0709",
     "qwen3-0.6b-FC",
     "qwen3-0.6b",
     "qwen3-1.7b-FC",
@@ -85,14 +83,19 @@ SUPPORTED_MODELS = [
     "qwen3-14b",
     "qwen3-32b-FC",
     "qwen3-32b",
-    "qwen3-30b-a3b-FC",
-    "qwen3-30b-a3b",
-    "qwen3-235b-a22b-FC",
-    "qwen3-235b-a22b",
+    "qwen3-30b-a3b-instruct-2507-FC",
+    "qwen3-30b-a3b-instruct-2507",
+    "qwen3-235b-a22b-instruct-2507-FC",
+    "qwen3-235b-a22b-instruct-2507",
     "qwq-32b-FC",
     "qwq-32b",
     "xiaoming-14B",
     "DM-Cito-8B-v2",
+    "Ling/ling-lite-v1.5",
+    "glm-4.5-FC",
+    "glm-4.5-air-FC",
+    "kimi-k2-0711-preview-FC",
+    "kimi-k2-0711-preview",
     "deepseek-ai/DeepSeek-R1",
     "google/gemma-3-1b-it",
     "google/gemma-3-4b-it",
@@ -116,6 +119,8 @@ SUPPORTED_MODELS = [
     "microsoft/phi-4",
     "microsoft/Phi-4-mini-instruct",
     "microsoft/Phi-4-mini-instruct-FC",
+    "ibm-granite/granite-3.2-8b-instruct",
+    "ibm-granite/granite-3.1-8b-instruct",
     "ibm-granite/granite-20b-functioncalling",
     "MadeAgents/Hammer2.1-7b",
     "MadeAgents/Hammer2.1-3b",
@@ -126,18 +131,18 @@ SUPPORTED_MODELS = [
     "Qwen/Qwen3-0.6B",
     "Qwen/Qwen3-1.7B-FC",
     "Qwen/Qwen3-1.7B",
-    "Qwen/Qwen3-4B-FC",
-    "Qwen/Qwen3-4B",
+    "Qwen/Qwen3-4B-Instruct-2507-FC",
+    "Qwen/Qwen3-4B-Instruct-2507",
     "Qwen/Qwen3-8B-FC",
     "Qwen/Qwen3-8B",
     "Qwen/Qwen3-14B-FC",
     "Qwen/Qwen3-14B",
     "Qwen/Qwen3-32B-FC",
     "Qwen/Qwen3-32B",
-    "Qwen/Qwen3-30B-A3B-FC",
-    "Qwen/Qwen3-30B-A3B",
-    "Qwen/Qwen3-235B-A22B-FC",
-    "Qwen/Qwen3-235B-A22B",
+    "Qwen/Qwen3-30B-A3B-Instruct-2507-FC",
+    "Qwen/Qwen3-30B-A3B-Instruct-2507",
+    "Qwen/Qwen3-235B-A22B-Instruct-2507-FC",
+    "Qwen/Qwen3-235B-A22B-Instruct-2507",
     "Team-ACE/ToolACE-2-8B",
     "openbmb/MiniCPM3-4B",
     "openbmb/MiniCPM3-4B-FC",
@@ -153,17 +158,20 @@ SUPPORTED_MODELS = [
     "uiuc-convai/CoALM-8B",
     "uiuc-convai/CoALM-70B",
     "uiuc-convai/CoALM-405B",
+    "katanemo/Arch-Agent-1.5B",
+    "katanemo/Arch-Agent-3B",
+    "katanemo/Arch-Agent-7B",
+    "katanemo/Arch-Agent-32B",
     "BitAgent/BitAgent-8B",
+    "BitAgent/BitAgent-Bounty-8B",
     "ThinkAgents/ThinkAgent-1B",
+    "phronetic-ai/RZN-T",
     "meta-llama/llama-4-maverick-17b-128e-instruct-fp8-novita",
     "meta-llama/llama-4-maverick-17b-128e-instruct-fp8-FC-novita",
     "meta-llama/llama-4-scout-17b-16e-instruct-novita",
     "meta-llama/llama-4-scout-17b-16e-instruct-FC-novita",
     "qwen/qwq-32b-FC-novita",
     "qwen/qwq-32b-novita",
-    "Ling/ling-lite-v1.5",
-    "katanemo/Arch-Agent-1.5B",
-    "katanemo/Arch-Agent-3B",
-    "katanemo/Arch-Agent-7B",
-    "katanemo/Arch-Agent-32B"
+    "qwen3-4b-think-FC",
+    "qwen3-4b-nothink-FC",
 ]
