@@ -1,21 +1,20 @@
 import os
 import time
+from typing import Any
 
 from bfcl_eval.constants.type_mappings import GORILLA_TO_OPENAPI
 from bfcl_eval.model_handler.base_handler import BaseHandler
-from bfcl_eval.model_handler.model_style import ModelStyle
+from bfcl_eval.constants.enums import ModelStyle
 from bfcl_eval.model_handler.utils import (
     convert_to_tool,
     default_decode_ast_prompting,
     default_decode_execute_prompting,
     extract_system_prompt,
     format_execution_results_prompting,
-    func_doc_language_specific_pre_processing,
     retry_with_backoff,
     system_prompt_pre_processing_chat_model,
 )
 from google import genai
-from google.genai import errors as genai_errors
 from google.genai.types import (
     AutomaticFunctionCallingConfig,
     Content,
@@ -48,19 +47,19 @@ class GeminiHandler(BaseHandler):
 
         return prompts
 
-    def decode_ast(self, result, language="Python"):
+    def decode_ast(self, result, language, has_tool_call_tag):
         if "FC" not in self.model_name:
             result = result.replace("```tool_code\n", "").replace("\n```", "")
-            return default_decode_ast_prompting(result, language)
+            return default_decode_ast_prompting(result, language, has_tool_call_tag)
         else:
             if type(result) is not list:
                 result = [result]
             return result
 
-    def decode_execute(self, result):
+    def decode_execute(self, result, has_tool_call_tag):
         if "FC" not in self.model_name:
             result = result.replace("```tool_code\n", "").replace("\n```", "")
-            return default_decode_execute_prompting(result)
+            return default_decode_execute_prompting(result, has_tool_call_tag)
         else:
             func_call_list = []
             for function_call in result:
@@ -123,16 +122,14 @@ class GeminiHandler(BaseHandler):
 
     def _compile_tools(self, inference_data: dict, test_entry: dict) -> dict:
         functions: list = test_entry["function"]
-        test_category: str = test_entry["id"].rsplit("_", 1)[0]
 
-        functions = func_doc_language_specific_pre_processing(functions, test_category)
         tools = convert_to_tool(functions, GORILLA_TO_OPENAPI, self.model_style)
 
         inference_data["tools"] = tools
 
         return inference_data
 
-    def _parse_query_response_FC(self, api_response: any) -> dict:
+    def _parse_query_response_FC(self, api_response: Any) -> dict:
         tool_call_func_names = []
         fc_parts = []
         text_parts = []
@@ -259,9 +256,7 @@ class GeminiHandler(BaseHandler):
 
     def _pre_query_processing_prompting(self, test_entry: dict) -> dict:
         functions: list = test_entry["function"]
-        test_category: str = test_entry["id"].rsplit("_", 1)[0]
-
-        functions = func_doc_language_specific_pre_processing(functions, test_category)
+        test_entry_id: str = test_entry["id"]
 
         for round_idx in range(len(test_entry["question"])):
             test_entry["question"][round_idx] = self._substitute_prompt_role(
@@ -269,7 +264,7 @@ class GeminiHandler(BaseHandler):
             )
 
         test_entry["question"][0] = system_prompt_pre_processing_chat_model(
-            test_entry["question"][0], functions, test_category
+            test_entry["question"][0], functions, test_entry_id
         )
         # Gemini has system prompt in a specific field
         system_prompt = extract_system_prompt(test_entry["question"][0])
@@ -279,7 +274,7 @@ class GeminiHandler(BaseHandler):
         else:
             return {"message": []}
 
-    def _parse_query_response_prompting(self, api_response: any) -> dict:
+    def _parse_query_response_prompting(self, api_response: Any) -> dict:
         if (
             len(api_response.candidates) > 0
             and api_response.candidates[0].content
@@ -300,6 +295,7 @@ class GeminiHandler(BaseHandler):
 
         else:
             model_responses = "The model did not return any response."
+            reasoning_content = ""
 
         return {
             "model_responses": model_responses,
