@@ -5,13 +5,19 @@ import json
 import operator
 import re
 from functools import reduce
-from typing import Callable, List, Optional, Type, Union
+from typing import TYPE_CHECKING, Callable, List, Optional, Type, Union
 
-from bfcl_eval.constants.default_prompts import DEFAULT_SYSTEM_PROMPT
+from bfcl_eval.constants.default_prompts import *
+from bfcl_eval.constants.enums import ModelStyle, ReturnFormat
 from bfcl_eval.constants.type_mappings import GORILLA_TO_OPENAPI
-from bfcl_eval.model_handler.model_style import ModelStyle
 from bfcl_eval.model_handler.parser.java_parser import parse_java_function_call
 from bfcl_eval.model_handler.parser.js_parser import parse_javascript_function_call
+from bfcl_eval.model_handler.parser.json_parser import parse_json_function_call
+from bfcl_eval.model_handler.parser.xml_parser import (
+    parse_concise_xml_function_call,
+    parse_verbose_xml_function_call,
+)
+from bfcl_eval.utils import *
 from tenacity import (
     retry,
     retry_if_exception_message,
@@ -19,6 +25,11 @@ from tenacity import (
     wait_random_exponential,
 )
 
+if TYPE_CHECKING:
+    from bfcl_eval.eval_checker.multi_turn_eval.func_source_code.memory_api_metaclass import (
+        MemoryAPI,
+    )
+
 
 def _cast_to_openai_type(properties, mapping):
     for key, value in properties.items():
@@ -70,12 +81,12 @@ def convert_to_tool(functions, mapping, model_style):
     oai_tool = []
     for item in functions:
         if "." in item["name"] and model_style in [
-            ModelStyle.OpenAI_Completions,
-            ModelStyle.OpenAI_Responses,
-            ModelStyle.Mistral,
+            ModelStyle.OPENAI_COMPLETIONS,
+            ModelStyle.OPENAI_RESPONSES,
+            ModelStyle.MISTRAL,
             ModelStyle.GOOGLE,
             ModelStyle.OSSMODEL,
-            ModelStyle.Anthropic,
+            ModelStyle.ANTHROPIC,
             ModelStyle.COHERE,
             ModelStyle.AMAZON,
             ModelStyle.NOVITA_AI,
@@ -88,7 +99,7 @@ def convert_to_tool(functions, mapping, model_style):
             item["parameters"]["properties"], mapping
         )
 
-        if model_style == ModelStyle.Anthropic:
+        if model_style == ModelStyle.ANTHROPIC:
             item["input_schema"] = item["parameters"]
             del item["parameters"]
 
@@ -157,7 +168,7 @@ def convert_to_tool(functions, mapping, model_style):
         # Process the return field
         if "response" in item:
             if model_style in [
-                ModelStyle.Anthropic,
+                ModelStyle.ANTHROPIC,
                 ModelStyle.GOOGLE,
                 ModelStyle.FIREWORK_AI,
                 ModelStyle.WRITER,
@@ -170,22 +181,24 @@ def convert_to_tool(functions, mapping, model_style):
                 del item["response"]
 
         if model_style in [
-            ModelStyle.Anthropic,
+            ModelStyle.ANTHROPIC,
             ModelStyle.GOOGLE,
             ModelStyle.OSSMODEL,
         ]:
             oai_tool.append(item)
-        elif model_style in [
-            ModelStyle.OpenAI_Responses
-        ]:
-            oai_tool.append({"type": "function", 
-                             "name": item["name"], 
-                             "description": item["description"], 
-                             "parameters": item["parameters"]})
+        elif model_style in [ModelStyle.OPENAI_RESPONSES]:
+            oai_tool.append(
+                {
+                    "type": "function",
+                    "name": item["name"],
+                    "description": item["description"],
+                    "parameters": item["parameters"],
+                }
+            )
         elif model_style in [
             ModelStyle.COHERE,
-            ModelStyle.OpenAI_Completions,
-            ModelStyle.Mistral,
+            ModelStyle.OPENAI_COMPLETIONS,
+            ModelStyle.MISTRAL,
             ModelStyle.FIREWORK_AI,
             ModelStyle.WRITER,
             ModelStyle.NOVITA_AI,
@@ -238,9 +251,21 @@ def convert_value(value, type_str):
         return value
 
 
-def ast_parse(input_str: str, language: str="Python") -> list[dict]:
-    if language == "Python":
-        cleaned_input = input_str.strip("[]'")
+def ast_parse(
+    input_str: str,
+    language: ReturnFormat = ReturnFormat.PYTHON,
+    has_tool_call_tag: bool = False,
+) -> list[dict]:
+    if has_tool_call_tag:
+        match = re.search(r"<TOOLCALL>(.*?)</TOOLCALL>", input_str, re.DOTALL)
+        if match:
+            input_str = match.group(1).strip()
+        else:
+            raise ValueError(f"No tool call tag found in input string: {input_str}")
+
+    if language == ReturnFormat.PYTHON:
+        # We only want to remove wrapping quotes that could have been added by the model.
+        cleaned_input = input_str.strip().strip("'")
         parsed = ast.parse(cleaned_input, mode="eval")
         extracted = []
         if isinstance(parsed.body, ast.Call):
@@ -250,12 +275,40 @@ def ast_parse(input_str: str, language: str="Python") -> list[dict]:
                 assert isinstance(elem, ast.Call)
                 extracted.append(resolve_ast_call(elem))
         return extracted
-    elif language == "Java":
-        return parse_java_function_call(
-            input_str[1:-1]
-        )  # Remove the [ and ] from the string
-    elif language == "JavaScript":
+
+    elif language == ReturnFormat.JAVA:
+        # Remove the [ and ] from the string
+        # Note: This is due to legacy reasons, we should fix this in the future.
+        return parse_java_function_call(input_str[1:-1])
+
+    elif language == ReturnFormat.JAVASCRIPT:
+        # Note: Same as above, we should fix this in the future.
         return parse_javascript_function_call(input_str[1:-1])
+
+    elif language == ReturnFormat.VERBOSE_XML:
+        # Remove ```xml and anything before/after XML
+        match = re.search(r"<functions>(.*?)</functions>", input_str, re.DOTALL)
+        if not match:
+            raise ValueError(
+                f"No XML function call found in input string: {input_str}. Missing <functions> tag."
+            )
+        return parse_verbose_xml_function_call(match.group(0))
+
+    elif language == ReturnFormat.CONCISE_XML:
+        # Remove anything before/after <functions> and </functions>
+        match = re.search(r"<functions>(.*?)</functions>", input_str, re.DOTALL)
+        if not match:
+            raise ValueError(
+                f"No XML function call found in input string: {input_str}. Missing <functions> tag."
+            )
+        return parse_concise_xml_function_call(match.group(0))
+
+    elif language == ReturnFormat.JSON:
+        json_match = re.search(r"\[.*\]", input_str, re.DOTALL)
+        if json_match:
+            input_str = json_match.group(0)
+        return parse_json_function_call(input_str)
+
     else:
         raise NotImplementedError(f"Unsupported language: {language}")
 
@@ -323,16 +376,21 @@ def resolve_ast_by_type(value):
     return output
 
 
-def system_prompt_pre_processing_chat_model(prompts, function_docs, test_category):
+# TODO: consider moving this step to pipeline instead of in each model handler
+def system_prompt_pre_processing_chat_model(
+    prompts: list[dict], function_docs: list[dict], test_entry_id: str
+) -> list[dict]:
     """
     Add a system prompt to the chat model to instruct the model on the available functions and the expected response format.
     If the prompts list already contains a system prompt, append the additional system prompt content to the existing system prompt.
     """
     assert type(prompts) == list
 
-    system_prompt_template = DEFAULT_SYSTEM_PROMPT
+    prompt_format = extract_prompt_format_from_id(test_entry_id)
 
-    system_prompt = system_prompt_template.format(functions=function_docs)
+    system_prompt = formulate_system_prompt(
+        format_sensitivity_config=prompt_format, functions=function_docs
+    )
 
     # System prompt must be in the first position
     # If the question comes with a system prompt, append its content at the end of the chat template.
@@ -377,284 +435,6 @@ def combine_consecutive_user_prompts(prompts: list[dict]) -> list[dict]:
     return combined_prompts
 
 
-def _get_language_specific_hint(test_category):
-    if test_category == "java":
-        return " Note that the provided function is in Java 8 SDK syntax."
-    elif test_category == "javascript":
-        return " Note that the provided function is in JavaScript syntax."
-    else:
-        return " Note that the provided function is in Python 3 syntax."
-
-
-def func_doc_language_specific_pre_processing(function, test_category):
-    if len(function) == 0:
-        return function
-
-    assert type(function) == list
-    for item in function:
-        # Add language specific hints to the function description
-        func_description = item["description"]
-        item["description"] = item["description"] + _get_language_specific_hint(
-            test_category
-        )
-        # Process the parameters
-        properties = item["parameters"]["properties"]
-        if test_category == "java":
-            for key, value in properties.items():
-                if value["type"] == "any":
-                    properties[key][
-                        "description"
-                    ] += " This parameter can be of any type of Java object in string representation."
-                else:
-                    value[
-                        "description"
-                    ] += f" This is Java {value['type']} type parameter in string representation."
-                if value["type"] == "ArrayList" or value["type"] == "Array":
-                    value[
-                        "description"
-                    ] += f" The list elements are of type {value['items']['type']}; they are not in string representation."
-                    del value["items"]
-
-                value["type"] = "string"
-
-        elif test_category == "javascript":
-            for key, value in properties.items():
-                if value["type"] == "any":
-                    properties[key][
-                        "description"
-                    ] += " This parameter can be of any type of JavaScript object in string representation."
-                else:
-                    value[
-                        "description"
-                    ] += f" This is JavaScript {value['type']} type parameter in string representation."
-                if value["type"] == "array":
-                    value[
-                        "description"
-                    ] += f" The list elements are of type {value['items']['type']}; they are not in string representation."
-                    del value["items"]
-
-                if value["type"] == "dict":
-                    if "properties" in value:  # not every dict has properties
-                        value[
-                            "description"
-                        ] += f" The dictionary entries have the following schema; they are not in string representation. {json.dumps(value['properties'])}"
-                        del value["properties"]
-
-                value["type"] = "string"
-
-    return function
-
-
-def construct_tool_use_system_prompt(tools):
-    tool_use_system_prompt = (
-        "In this environment you have access to a set of tools you can use to answer the user's question.\n"
-        "\n"
-        "You may call them like this:\n"
-        "<function_calls>\n"
-        "<invoke>\n"
-        "<tool_name>$TOOL_NAME</tool_name>\n"
-        "<parameters>\n"
-        "<$PARAMETER_NAME>$PARAMETER_VALUE</$PARAMETER_NAME>\n"
-        "...\n"
-        "</parameters>\n"
-        "</invoke>\n"
-        "</function_calls>\n"
-        "\n"
-        "Here are the tools available:\n"
-        "<tools>\n"
-        + "\n".join(
-            [
-                construct_format_tool_for_claude_prompt(
-                    tool["name"], tool["description"], tool["parameters"]["properties"]
-                )
-                for tool in tools
-            ]
-        )
-        + "\n</tools>"
-    )
-
-    return tool_use_system_prompt
-
-
-def construct_format_tool_for_claude_prompt(name, description, parameters):
-    constructed_prompt = (
-        "<tool_description>\n"
-        f"<tool_name>{name}</tool_name>\n"
-        "<description>\n"
-        f"{description}\n"
-        "</description>\n"
-        "<parameters>\n"
-        f"{construct_format_parameters_prompt(parameters)}\n"
-        "</parameters>\n"
-        "</tool_description>"
-    )
-
-    return constructed_prompt
-
-
-def construct_format_parameters_prompt(parameters):
-    constructed_prompt = ""
-    for parameter_name, parameter in parameters.items():
-        if parameter_name == "required":
-            continue
-        if "description" in parameter:
-            description_string = parameter["description"]
-        else:
-            description_string = ""
-        if "default" in parameter:
-            description_string += f"\nDefault value: {parameter['default']}"
-        elif "items" in parameter:
-            description_string += f"\n List element type: {str(parameter['items'])}"
-        elif "properties" in parameter:
-            description_string += (
-                f"\n Dictionaries properties: {str(parameter['properties'])}"
-            )
-        if "description" in parameter:
-            constructed_prompt += f"<parameter>\n<name>{parameter_name}</name>\n<type>{parameter['type']}</type>\n<description>{description_string}</description>\n</parameter>\n"
-        else:
-            constructed_prompt += f"<parameter>\n<name>{parameter_name}</name>\n<type>{parameter['type']}</type>\n</parameter>\n"
-    constructed_prompt = constructed_prompt[:-1]
-    return constructed_prompt
-
-
-def _function_calls_valid_format_and_invoke_extraction(last_completion):
-    """Check if the function call follows a valid format and extract the attempted function calls if so. Does not check if the tools actually exist or if they are called with the requisite params."""
-
-    # Check if there are any of the relevant XML tags present that would indicate an attempted function call.
-    function_call_tags = re.findall(
-        r"<function_calls>|</function_calls>|<invoke>|</invoke>|<tool_name>|</tool_name>|<parameters>|</parameters>",
-        last_completion,
-        re.DOTALL,
-    )
-    if not function_call_tags:
-        return {"status": True, "invokes": []}
-
-    # Extract content between <function_calls> tags. If there are multiple we will only parse the first and ignore the rest, regardless of their correctness.
-    match = re.search(r"<function_calls>(.*)</function_calls>", last_completion, re.DOTALL)
-    if not match:
-        return {
-            "status": False,
-            "reason": "No valid <function_calls></function_calls> tags present in your query.",
-        }
-
-    func_calls = match.group(1)
-
-    prefix_match = re.search(r"^(.*?)<function_calls>", last_completion, re.DOTALL)
-    if prefix_match:
-        func_call_prefix_content = prefix_match.group(1)
-
-    # Check for invoke tags
-    invoke_regex = r"<invoke>.*?</invoke>"
-    if not re.search(invoke_regex, func_calls, re.DOTALL):
-        return {
-            "status": False,
-            "reason": "Missing <invoke></invoke> tags inside of <function_calls></function_calls> tags.",
-        }
-
-    # Check each invoke contains tool name and parameters
-    invoke_strings = re.findall(invoke_regex, func_calls, re.DOTALL)
-    invokes = []
-    for invoke_string in invoke_strings:
-        tool_name = re.findall(r"<tool_name>.*?</tool_name>", invoke_string, re.DOTALL)
-        if not tool_name:
-            return {
-                "status": False,
-                "reason": "Missing <tool_name></tool_name> tags inside of <invoke></invoke> tags.",
-            }
-        if len(tool_name) > 1:
-            return {
-                "status": False,
-                "reason": "More than one tool_name specified inside single set of <invoke></invoke> tags.",
-            }
-
-        parameters = re.findall(r"<parameters>.*?</parameters>", invoke_string, re.DOTALL)
-        if not parameters:
-            return {
-                "status": False,
-                "reason": "Missing <parameters></paraeters> tags inside of <invoke></invoke> tags.",
-            }
-        if len(parameters) > 1:
-            return {
-                "status": False,
-                "reason": "More than one set of <parameters></parameters> tags specified inside single set of <invoke></invoke> tags.",
-            }
-
-        # Check for balanced tags inside parameters
-        tags = re.findall(
-            r"<.*?>",
-            parameters[0].replace("<parameters>", "").replace("</parameters>", ""),
-            re.DOTALL,
-        )
-        if len(tags) % 2 != 0:
-            return {
-                "status": False,
-                "reason": "Imbalanced tags inside <parameters></parameters> tags.",
-            }
-
-        # Loop through the tags and check if each even-indexed tag matches the tag in the position after it (with the / of course). If valid store their content for later use.
-        parameters_with_values = []
-        for i in range(0, len(tags), 2):
-            opening_tag = tags[i]
-            closing_tag = tags[i + 1]
-            closing_tag_without_second_char = closing_tag[:1] + closing_tag[2:]
-            if closing_tag[1] != "/" or opening_tag != closing_tag_without_second_char:
-                return {
-                    "status": False,
-                    "reason": "Non-matching opening and closing tags inside <parameters></parameters> tags.",
-                }
-
-            parameters_with_values.append(
-                (
-                    opening_tag[1:-1],
-                    re.search(
-                        rf"{opening_tag}(.*?){closing_tag}", parameters[0], re.DOTALL
-                    ).group(1),
-                )
-            )
-
-        # Parse out the full function call
-        invokes.append(
-            {
-                "tool_name": tool_name[0]
-                .replace("<tool_name>", "")
-                .replace("</tool_name>", ""),
-                "parameters_with_values": parameters_with_values,
-            }
-        )
-
-    return {
-        "status": True,
-        "invokes": invokes,
-        "prefix_content": func_call_prefix_content,
-    }
-
-
-def _convert_value(value, type_str):
-    """Convert a string value into its appropriate Python data type based on the provided type string.
-
-    Arg:
-        value: the value to convert
-        type_str: the type to convert the value to
-
-    Returns:
-        The value converted into the requested type or the original value
-        if the conversion failed.
-    """
-
-    if type_str in ("list", "dict"):
-        try:
-            return ast.literal_eval(value)
-        except:
-            return value
-    if type_str == "string":
-        type_str = "str"
-    type_class = getattr(builtins, type_str)
-    try:
-        return type_class(value)
-    except ValueError:
-        return value
-
-
 # TODO: Re-organize this file to make it more readable and maintainable
 def extract_system_prompt(prompts: list[dict]) -> str:
     for i, prompt in enumerate(prompts):
@@ -692,23 +472,32 @@ def format_execution_results_prompting(
     return repr(tool_results)
 
 
-def default_decode_ast_prompting(result: str, language: str="Python") -> list[dict]:
+def default_decode_ast_prompting(
+    result: str,
+    language: ReturnFormat = ReturnFormat.PYTHON,
+    has_tool_call_tag: bool = False,
+) -> list[dict]:
     result = result.strip("`\n ")
     if not result.startswith("["):
         result = "[" + result
     if not result.endswith("]"):
         result = result + "]"
-    decoded_output = ast_parse(result, language)
+    decoded_output = ast_parse(result, language, has_tool_call_tag)
     return decoded_output
 
 
-def default_decode_execute_prompting(result: str) -> list[str]:
+def default_decode_execute_prompting(
+    result: str, has_tool_call_tag: bool = False
+) -> list[str]:
+    # Note: For execute, there are only Python entries, so we don't need to check the language.
     result = result.strip("`\n ")
     if not result.startswith("["):
         result = "[" + result
     if not result.endswith("]"):
         result = result + "]"
-    decoded_output = ast_parse(result)
+    decoded_output = ast_parse(
+        result, language=ReturnFormat.PYTHON, has_tool_call_tag=has_tool_call_tag
+    )
     return decoded_output_to_execution_list(decoded_output)
 
 
@@ -819,3 +608,320 @@ def retry_with_backoff(
         return wrapped
 
     return decorator
+
+
+#### utils for memory category ####
+
+
+def add_memory_instruction_system_prompt(
+    prompts: list[list[dict]],
+    test_category: str,
+    scenario: str,
+    memory_backend_instance: "MemoryAPI",
+) -> list[list[dict]]:
+    """
+    Memory categories requires a system prompt that instructs the model on how to use the memory backend, and also provides the content in core memory (if applicable).
+    The input for prompts is a list of list of dictionaries, where each outer list item represents a conversation turn, and each inner list item represents a message in that turn.
+    System prompt are added as the first message in the first turn of the conversation.
+    """
+    assert len(prompts) >= 1
+
+    scenario_setting = MEMORY_AGENT_SETTINGS[scenario]
+
+    memory_content = memory_backend_instance._dump_core_memory_to_context()
+
+    if "rec_sum" in test_category:
+        system_prompt_template = MEMORY_BACKEND_INSTRUCTION_UNIFIED
+    else:
+        system_prompt_template = MEMORY_BACKEND_INSTRUCTION_CORE_ARCHIVAL
+
+    system_prompt = system_prompt_template.format(
+        scenario_setting=scenario_setting, memory_content=memory_content
+    )
+
+    # System prompt must be in the first position
+    # If the question comes with a system prompt, append its content at the end of the chat template.
+    first_turn_prompts = prompts[0]
+    if first_turn_prompts[0]["role"] == "system":
+        first_turn_prompts[0]["content"] = (
+            system_prompt + "\n\n" + first_turn_prompts[0]["content"]
+        )
+    # Otherwise, use the system prompt template to create a new system prompt.
+    else:
+        first_turn_prompts.insert(
+            0,
+            {"role": "system", "content": system_prompt},
+        )
+
+    return prompts
+
+
+#### Utils for Format Sensitivity ####
+
+
+def formulate_system_prompt(format_sensitivity_config: str, functions: list[dict]) -> str:
+    """
+    Formulate the default system prompt based on the provided parameters.
+    """
+    (
+        return_format,
+        has_tool_call_tag,
+        function_doc_format,
+        prompt_format,
+        prompt_style,
+    ) = parse_prompt_variation_params(format_sensitivity_config)
+
+    formatted_function_doc = format_function_doc(functions, function_doc_format)
+
+    prompt_template = PROMPT_TEMPLATE_MAPPING[prompt_format]
+    style_template = PROMPT_STYLE_TEMPLATES[prompt_style]
+
+    persona = style_template["persona"]
+    task = style_template["task"]
+    if has_tool_call_tag:
+        tool_call_format = style_template["tool_call_with_tag"].format(
+            output_format=OUTPUT_FORMAT_MAPPING[return_format],
+            param_types=PARAM_TYPE_MAPPING[return_format],
+        )
+    else:
+        tool_call_format = style_template["tool_call_no_tag"].format(
+            output_format=OUTPUT_FORMAT_MAPPING[return_format],
+            param_types=PARAM_TYPE_MAPPING[return_format],
+        )
+    multiturn_behavior = style_template["multiturn_behavior"]
+    available_tools = style_template["available_tools"].format(
+        format=function_doc_format,
+        functions=formatted_function_doc,
+    )
+
+    system_prompt = prompt_template.format(
+        persona=persona,
+        task=task,
+        tool_call_format=tool_call_format,
+        multiturn_behavior=multiturn_behavior,
+        available_tools=available_tools,
+    )
+
+    return system_prompt
+
+
+def format_function_doc(functions: list[dict], function_doc_format: str) -> str:
+    """
+    Format the function documentation based on the specified format.
+    """
+
+    if function_doc_format == "xml":
+        functions = _generate_function_doc_xml(functions)
+
+    elif function_doc_format == "python":
+        functions = _generate_function_doc_python(functions)
+
+    elif function_doc_format == "json":
+        functions = json.dumps(functions, indent=4)
+
+    else:
+        raise ValueError(f"Invalid function doc format: {function_doc_format}")
+
+    return functions
+
+
+def _generate_function_doc_xml(functions: list[dict]) -> str:
+    """
+    Generate the function documentation in XML format.
+    """
+
+    def _param_xml(
+        name: str, meta: dict, required_set: Optional[list[str]], indent_lvl: int = 2
+    ) -> str:
+        """Recursively render a param and its nested structure to XML."""
+        indent = " " * indent_lvl * 2  # 2 spaces per logical indent level
+
+        p_type = meta.get("type", "string")
+        p_desc = meta.get("description", "")
+        # If there is no required set, then all parameters are required by default.
+        if required_set is None:
+            is_required = "true"
+        else:
+            is_required = "true" if name in required_set else "false"
+
+        # Handle enum values
+        if "enum" in meta:
+            p_desc += f" Enum values: {meta['enum']}."
+
+        # Handling for array/tuple/list types
+        if "items" in meta and "type" in meta["items"]:
+            inner_type = meta["items"]["type"]
+            p_type = f"{p_type}[{inner_type}]"
+
+        elif "additionalProperties" in meta:
+            inner_type = meta["additionalProperties"].get("type", "string")
+            p_type = f"{p_type}[{inner_type}]"
+
+        # Build opening tag (include default attr if exists)
+        attrs = [f'name="{name}", type="{p_type}", required="{is_required}"']
+        if "default" in meta:
+            attrs.append(f'default="{repr(meta["default"])}"')
+        open_tag = f"{indent}<param " + " ".join(attrs).replace(",", "") + ">\n"
+
+        xml_parts = [open_tag]
+        xml_parts.append(f"{indent}  <desc>{p_desc}</desc>\n")
+
+        # Recursive handling for object/dict types
+        if "properties" in meta:
+            child_required = meta.get("required", None)
+            xml_parts.append(f"{indent}  <params>\n")
+            for child_name, child_meta in meta["properties"].items():
+                xml_parts.append(
+                    _param_xml(child_name, child_meta, child_required, indent_lvl + 2)
+                )
+            xml_parts.append(f"{indent}  </params>\n")
+
+        # closing tag
+        xml_parts.append(f"{indent}</param>\n")
+        return "".join(xml_parts)
+
+    xml_blocks: list[str] = []
+    for fn in functions:
+        name = fn["name"]
+        desc = fn.get("description", "")
+
+        params_schema = fn["parameters"]
+        top_props = params_schema.get("properties", {})
+        top_required = params_schema.get("required", None)
+
+        xml = f'<function name="{name}">\n'
+        xml += f"  <desc>{desc}</desc>\n"
+        xml += f"  <params>\n"
+
+        for param_name, meta in top_props.items():
+            xml += _param_xml(param_name, meta, top_required, indent_lvl=2)
+
+        xml += f"  </params>\n"
+        xml += f"</function>\n"
+        xml_blocks.append(xml)
+
+    return "\n".join(xml_blocks)
+
+
+def _generate_function_doc_python(functions: list[dict]) -> str:
+    """
+    Generate the function documentation in Pythonic format.
+    """
+
+    def _to_py_type(meta: dict) -> str:
+        t = meta.get("type", "string")
+        primitive_map = {
+            "string": "str",
+            "number": "float",
+            "integer": "int",
+            "boolean": "bool",
+        }
+
+        if t in primitive_map:
+            return primitive_map[t]
+
+        if t in {"array", "list", "tuple"} and "items" in meta:
+            return f"list[{_to_py_type(meta['items'])}]"
+
+        if t in {"object", "dict"}:
+            if "additionalProperties" in meta:
+                return f"dict[str, {_to_py_type(meta['additionalProperties'])}]"
+            # If specific properties, treat as dict
+            return "dict"
+
+        # Fallback
+        return t
+
+    INDENT_BASE = " " * 8  # 8 spaces inside the docstring block
+
+    def _param_doc(name: str, meta: dict, depth: int = 0) -> list[str]:
+        """Recursively build docstring lines for a parameter schema."""
+        lines: list[str] = []
+        indent = INDENT_BASE + (" " * 4 * depth)
+
+        py_type = _to_py_type(meta)
+        desc = meta.get("description", "")
+        if "enum" in meta:
+            desc += f" Enum values: {meta['enum']}."
+
+        if "default" in meta:
+            default_note = f", default={repr(meta['default'])}"
+        else:
+            default_note = ""
+        lines.append(f"{indent}{name} ({py_type}{default_note}): {desc}\n")
+
+        # Handle nested object properties
+        if "properties" in meta:
+            for child_name, child_meta in meta["properties"].items():
+                lines.extend(_param_doc(f"{child_name}", child_meta, depth + 1))
+
+        return lines
+
+    docs: list[str] = []
+    for fn in functions:
+        full_name = fn["name"]
+        desc = fn.get("description", "")
+
+        doc_lines: list[str] = []
+        doc_lines.append(f"# Function: {full_name}\n")
+        doc_lines.append('    """\n')
+        doc_lines.append(f"    {desc}\n\n")
+
+        params_schema = fn.get("parameters", {})
+        top_props = params_schema.get("properties", {})
+
+        if top_props:
+            doc_lines.append("    Args:\n")
+            for param_name, meta in top_props.items():
+                doc_lines.extend(_param_doc(param_name, meta))
+
+        doc_lines.append('    """\n')
+        docs.append("".join(doc_lines))
+        docs.append("\n")
+
+    return "\n\n".join(docs)
+
+
+def parse_prompt_variation_params(input_str: str) -> tuple[str, bool, str, str, str]:
+    """
+    Parse a query string of the form:
+      ret_fmt=…&tool_call_tag=…&func_doc_fmt=…&prompt_fmt=…&style=…
+
+    Returns a 5-tuple containing, **in order**:
+        1. return_format (str)
+        2. has_tool_call_tag (bool)
+        3. function_doc_format (str)
+        4. prompt_format (str)
+        5. prompt_style (str)
+
+    Raises:
+        ValueError: If the input string does not conform to the expected format.
+    """
+    _PATTERN = re.compile(
+        r"^"
+        r"ret_fmt=(?P<return_format>python|json|verbose_xml|concise_xml)"
+        r"&tool_call_tag=(?P<has_tool_call_tag>True|False)"
+        r"&func_doc_fmt=(?P<function_doc_format>python|xml|json)"
+        r"&prompt_fmt=(?P<prompt_format>plaintext|markdown)"
+        r"&style=(?P<prompt_style>classic|experimental)"
+        r"$"
+    )
+
+    match = _PATTERN.match(input_str)
+    if not match:
+        raise ValueError(f"Invalid query format: {input_str!r}")
+
+    # Extract named groups
+    return_format = match.group("return_format")
+    has_tool_call_tag = match.group("has_tool_call_tag") == "True"
+    function_doc_format = match.group("function_doc_format")
+    prompt_format = match.group("prompt_format")
+    prompt_style = match.group("prompt_style")
+
+    return (
+        return_format,
+        has_tool_call_tag,
+        function_doc_format,
+        prompt_format,
+        prompt_style,
+    )
